==> beanvalidation-tck-dist-2.0.5.tar.gz: beanvalidation-tck-dist-2.0.5/src/tests/src/main/java/org/hibernate/beanvalidation/tck/tests/integration/cdi/executable/ValidAnotherBookingService.java <==
/**
 * Jakarta Bean Validation TCK
 *
 * License: Apache License, Version 2.0
 * See the license.txt file in the root directory or <http://www.apache.org/licenses/LICENSE-2.0>.
 */
package org.hibernate.beanvalidation.tck.tests.integration.cdi.executable;

import static java.lang.annotation.ElementType.CONSTRUCTOR;
import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import javax.validation.Constraint;
import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;
import javax.validation.Payload;

/**
 * @author Gunnar Morling
 */
@Documented
@Constraint(validatedBy = ValidAnotherBookingService.Validator.class)
@Target({ METHOD, CONSTRUCTOR, TYPE, FIELD })
@Retention(RUNTIME)
public @interface ValidAnotherBookingService {
	String message() default "default message";

	Class<?>[] groups() default { };

	Class<? extends Payload>[] payload() default { };

	public static class Validator implements ConstraintValidator<ValidAnotherBookingService, AnotherBookingService> {

		@Override
		public boolean isValid(AnotherBookingService service, ConstraintValidatorContext constraintValidatorContext) {
			return Integer.parseInt( AnotherBookingService.getName() ) > 10000;
		}
	}
}

==> beanvalidation-tck-dist-3.0.1.tar.gz: beanvalidation-tck-dist-3.0.1/src/tests/src/main/java/org/hibernate/beanvalidation/tck/tests/integration/cdi/executable/ValidAnotherBookingService.java <==
/**
 * Jakarta Bean Validation TCK
 *
 * License: Apache License, Version 2.0
 * See the license.txt file in the root directory or <http://www.apache.org/licenses/LICENSE-2.0>.
 */
package org.hibernate.beanvalidation.tck.tests.integration.cdi.executable;

import static java.lang.annotation.ElementType.CONSTRUCTOR;
import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import jakarta.validation.Constraint;
import jakarta.validation.ConstraintValidator;
import jakarta.validation.ConstraintValidatorContext;
import jakarta.validation.Payload;

/**
 * @author Gunnar Morling
 */
@Documented
@Constraint(validatedBy = ValidAnotherBookingService.Validator.class)
@Target({ METHOD, CONSTRUCTOR, TYPE, FIELD })
@Retention(RUNTIME)
public @interface ValidAnotherBookingService {
	String message() default "default message";

	Class<?>[] groups() default { };

	Class<? extends Payload>[] payload() default { };

	public static class Validator implements ConstraintValidator<ValidAnotherBookingService, AnotherBookingService> {

		@Override
		public boolean isValid(AnotherBookingService service, ConstraintValidatorContext constraintValidatorContext) {
			return Integer.parseInt( AnotherBookingService.getName() ) > 10000;
		}
	}
}
